@@ -22,3 +22,8 @@ class AzureBlobStorageBackendTestCase(test_local.LocalDiskBackendTestCase):
             'base_path': os.path.join('tmp', bytes.hex(os.urandom(16)))
         }
 
+    def test_update_labels(self):
+        labels = {}
+        self.backend.update_labels(labels)
+        self.assertIn('azure.microsoft.com/blob-storage-account', labels)
+        self.assertIn('azure.microsoft.com/blob-storage-container', labels)
